@@ -53,7 +53,7 @@ class Queue(OrchestratorHTTP):
         data = self._get(url)
         return data
 
-    def start(self, machine_identifier, specific_content):
+    def start(self, machine_identifier, specific_content=None):
         """
             Starts a given transaction
 
@@ -68,6 +68,9 @@ class Queue(OrchestratorHTTP):
                 "SpecificContent": specific_content
             }
         }
+        if not specific_content:
+            format_body_start["transactionData"]["SpecificContent"] = None
+        print(format_body_start)
         url = f"{self.base_url}{endpoint}"
         return self._post(url, body=format_body_start)
 
@@ -161,29 +164,37 @@ class Queue(OrchestratorHTTP):
         # pprint(format_body_queue)
         return self._post(url, body=format_body_queue)
 
-    def _format_specific_content(self, queue_name, sp_content, priority="Low", progress="New", reference=None, batch_id=None):
+    def _format_specific_content(self, queue_name, sp_content, reference=None, priority="Low", progress="New", batch_id=None):
         ran_uuid = str(uuid4())
-        sp_content.update({"ReferenceID": ran_uuid})
-        sp_content.update({"BatchID": batch_id})
-        formatted_sp_content = {
-            "Name": queue_name,
-            "Priority": priority,
-            "SpecificContent": sp_content,
-            "Progress": progress,
-
-
-        }
-        try:
-            if reference:
+        if reference:
+            try:
                 ref_uuid = {"Reference": f"{sp_content[reference]}#{batch_id}"}
+                sp_content.update({"ReferenceID": ran_uuid})
+                sp_content.update({"BatchID": batch_id})
+                sp_content.update({"ItemID": sp_content[reference]})
+                formatted_sp_content = {
+                    "Name": queue_name,
+                    "Priority": priority,
+                    "SpecificContent": sp_content,
+                    "Progress": progress,
+                }
                 formatted_sp_content.update(ref_uuid)
-                formatted_sp_content.update({"ItemID": sp_content[reference]})
-            else:
-                formatted_sp_content.update({"Reference": batch_id})
-        except KeyError:
-            raise
-
-        return formatted_sp_content
+                return formatted_sp_content
+            except KeyError as err:
+                if reference in err.args:
+                    raise Exception(f"Invalid reference: {reference} not found in sp_content")
+        else:
+            ref_uuid = {"Reference": f"{ran_uuid}"}
+            sp_content.update({"ReferenceID": ran_uuid})
+            sp_content.update({"BatchID": batch_id})
+            formatted_sp_content = {
+                "Name": queue_name,
+                "Priority": priority,
+                "SpecificContent": sp_content,
+                "Progress": progress,
+            }
+            formatted_sp_content.update(ref_uuid)
+            return formatted_sp_content
 
     def bulk_create_items(self, specific_contents=None, priority="Low", progress="New", reference=None):
         """Adds a list of items for a given queue
@@ -196,6 +207,11 @@ class Queue(OrchestratorHTTP):
             @progress: sets up the progress bar (default: New)
             @reference: indicates a specific field of the specific content to
             be used as a queue reference.
+
+            Specific Content includes by default the following columns:
+                - BatchID: representing a unique ID for the specific batch of items to be uploaded
+                - ReferenceID: a unique ID of the item
+                - ItemID: if reference is set to true, ads a new field with the reference
         """
         endpoint = "/Queues"
         uipath_svc = "/UiPathODataSvc.BulkAddQueueItems"
@@ -203,11 +219,11 @@ class Queue(OrchestratorHTTP):
         if not specific_contents:
             raise OrchestratorMissingParam(value="specific_contents", message="specific contents cannot be null")
 
-        batch_id = str(uuid4)
+        batch_id = str(uuid4())
         format_body_queue = {
             "commitType": "StopOnFirstFailure",
             "queueName": self.name,
-            "queueItems": [self._format_specific_content(queue_name=self.name, sp_content=sp_content, priority=priority, progress=progress, reference=reference, batch_id=batch_id) for sp_content in specific_contents]
+            "queueItems": [self._format_specific_content(queue_name=self.name, sp_content=sp_content, reference=reference, priority=priority, progress=progress, batch_id=batch_id) for sp_content in specific_contents]
         }
         # pprint(format_body_queue)
         return self._post(url, body=format_body_queue)
